@@ -9,15 +9,12 @@ OC.L10N.register(
     "New folder" : "Pasgan ùr",
     "Move" : "Gluais",
     "Share" : "Co-roinn",
-    "Settings" : "Roghainnean",
     "Default" : "Bunaiteach",
+    "Settings" : "Roghainnean",
     "Rename" : "Thoir ainm ùr air",
     "Delete" : "Sguab às",
     "Newest first" : "As ùire an toiseach",
     "Oldest first" : "As sine an toiseach",
-    "Refresh" : "Ath-nuadhaich",
-    "Create" : "Cruthaich",
-    "Dismiss" : "Leig seachad",
-    "Help" : "Cobhair"
+    "Refresh" : "Ath-nuadhaich"
 },
 "nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
